::: tppt
    options:
      show_root_heading: true
      show_root_full_path: true
      show_category_heading: true
      show_if_no_docstring: true
      show_signature_annotations: true
      show_bases: true
      show_submodules: true
      group_by_category: true
      heading_level: 2
      members_order: source
    selection:
      docstring_style: google
      filters: ["!^_"] 